@@ -534,11 +534,11 @@ dos_date_to_tmu_date (uLong ulDosDate,
  * @param pfile_info file information to initialize
  * @param pfile_info_internal internal file information to initialize
  * @param szFileName where to write the name of the current file
- * @param fileNameBufferSize number of bytes available in szFileName
+ * @param fileNameBufferSize number of bytes available in @a szFileName
  * @param extraField where to write extra data
  * @param extraFieldBufferSize number of bytes available in extraField
  * @param szComment where to write the comment on the current file
- * @param commentBufferSize number of bytes available in szComment
+ * @param commentBufferSize number of bytes available in @a szComment
  * @return #EXTRACTOR_UNZIP_OK if there is no problem.
  */
 static int
@@ -664,7 +664,10 @@ get_current_file_info (struct EXTRACTOR_UnzipFile *file,
 	  uSizeRead = file_info.size_file_comment;
         }
       else
-	uSizeRead = commentBufferSize;
+        {
+          *(szComment+commentBufferSize - 1) = '\0';
+          uSizeRead = commentBufferSize - 1;
+        }
 
       if (0 != lSeek)
 	{
