@@ -36,7 +36,7 @@
 #include <unistd.h>
 #include <stdlib.h>
 
-  
+
 
 /**
  * Signature of the extract method that each plugin
@@ -44,7 +44,7 @@
  *
  * @param ec extraction context provided to the plugin
  */
-void
+_EXTRACTOR_EXTERN void
 EXTRACTOR_test_extract_method (struct EXTRACTOR_ExtractContext *ec)
 {
   void *dp;
@@ -54,19 +54,19 @@ EXTRACTOR_test_extract_method (struct EXTRACTOR_ExtractContext *ec)
   if (4 != ec->read (ec->cls, &dp, 4))
     {
       fprintf (stderr, "Reading at offset 0 failed\n");
-      ABORT (); 
+      ABORT ();
     }
   if (0 != strncmp ("test", dp, 4))
     {
       fprintf (stderr, "Unexpected data at offset 0\n");
-      ABORT (); 
+      ABORT ();
     }
   if ( (1024 * 150 != ec->get_size (ec->cls)) &&
        (UINT64_MAX != ec->get_size (ec->cls)) )
     {
       fprintf (stderr, "Unexpected file size returned (expected 150k)\n");
-      ABORT (); 
-    }		    
+      ABORT ();
+    }
   if (1024 * 100 + 4 != ec->seek (ec->cls, 1024 * 100 + 4, SEEK_SET))
     {
       fprintf (stderr, "Failure to seek (SEEK_SET)\n");
