@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     Copyright (C) 2004, 2005, 2006, 2007, 2009, 2012 Vidyut Samanta and Christian Grothoff
+     Copyright (C) 2004, 2005, 2006, 2007, 2009, 2012, 2018 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -173,7 +173,7 @@ struct ProcContext
   EXTRACTOR_MetaDataProcessor proc;
 
   /**
-   * Closure for 'proc'.
+   * Closure for @e proc.
    */
   void *proc_cls;
 
@@ -213,7 +213,12 @@ process_metadata (gpointer key,
 
   if (G_VALUE_TYPE(gval) == G_TYPE_STRING)
     {
-      contents = strdup (g_value_get_string (gval));
+      const char *gvals;
+
+      gvals = g_value_get_string (gval);
+      if (NULL == gvals)
+        return;
+      contents = strdup (gvals);
     }
   else
     {
