@@ -31,7 +31,7 @@
  * (2) ffmpeg has a history of having security issues (parser is not robust)
  *
  *  So this plugin cannot be recommended for system with high security
- *requirements. 
+ *requirements.
  */
 #include "platform.h"
 #include "extractor.h"
@@ -76,12 +76,12 @@
 
 /**
  * Set to 1 to enable debug output.
- */ 
+ */
 #define DEBUG 0
 
 /**
  * Set to 1 to enable a output file for testing.
- */ 
+ */
 #define OUTPUT_FILE 0
 
 
@@ -178,16 +178,19 @@ seek_cb (void *opaque,
  * @param pBufferSize , amount to write
  * @return 0 on error
  */
-static int writePacket(void *opaque, unsigned char *pBuffer, int pBufferSize) {
+static int
+writePacket (void *opaque,
+             unsigned char *pBuffer,
+             int pBufferSize)
+{
+  int sizeToCopy = pBufferSize;
 
-	int sizeToCopy = pBufferSize;
-	if( (totalSize + pBufferSize) > HARD_LIMIT_SIZE)
-		sizeToCopy = HARD_LIMIT_SIZE - totalSize;
+  if( (totalSize + pBufferSize) > HARD_LIMIT_SIZE)
+    sizeToCopy = HARD_LIMIT_SIZE - totalSize;
 
-    memcpy(buffer + totalSize, pBuffer, sizeToCopy);
-	totalSize+= sizeToCopy;
-	
-	return sizeToCopy;
+  memcpy (buffer + totalSize, pBuffer, sizeToCopy);
+  totalSize += sizeToCopy;
+  return sizeToCopy;
 }
 
 
@@ -201,19 +204,17 @@ static int open_output_file(
                             AVFormatContext **output_format_context,
                             AVCodecContext **output_codec_context)
 {
-	AVStream *stream               = NULL;
-    AVCodec *output_codec          = NULL;
-	AVIOContext *io_ctx;
-    int error;
-	
-
-	unsigned char *iob;
+  AVStream *stream               = NULL;
+  AVCodec *output_codec          = NULL;
+  AVIOContext *io_ctx;
+  int error;
+  unsigned char *iob;
 
   if (NULL == (iob = av_malloc (16 * 1024)))
     return AVERROR_EXIT;
   if (NULL == (io_ctx = avio_alloc_context (iob, 16 * 1024,
-					    AVIO_FLAG_WRITE, NULL, 
-					   NULL,
+					    AVIO_FLAG_WRITE, NULL,
+                                            NULL,
 					    &writePacket /* no writing */,
 					    NULL)))
     {
@@ -226,98 +227,107 @@ static int open_output_file(
       return AVERROR_EXIT;
     }
   (*output_format_context)->pb = io_ctx;
-  
+
     /** Guess the desired container format based on the file extension. */
-    if (!((*output_format_context)->oformat = av_guess_format(NULL, "file.ogg",
-                                                              NULL))) {
-#if DEBUG															  
-        fprintf(stderr, "Could not find output file format\n");
-#endif
-        goto cleanup;
-    }
-	
-
-    /** Find the encoder to be used by its name. */
-    if (!(output_codec = avcodec_find_encoder(AV_CODEC_ID_OPUS))) {
+  if (!((*output_format_context)->oformat = av_guess_format (NULL,
+                                                             "file.ogg",
+                                                             NULL)))
+    {
 #if DEBUG
-        fprintf(stderr, "Could not find an OPUS encoder.\n");
+      fprintf(stderr, "Could not find output file format\n");
 #endif
-        goto cleanup;
+      goto cleanup;
     }
 
-    /** Create a new audio stream in the output file container. */
-    if (!(stream = avformat_new_stream(*output_format_context, output_codec))) {
+  /** Find the encoder to be used by its name. */
+  if (!(output_codec = avcodec_find_encoder(AV_CODEC_ID_OPUS)))
+    {
 #if DEBUG
-        fprintf(stderr, "Could not create new stream\n");
+      fprintf(stderr, "Could not find an OPUS encoder.\n");
 #endif
-        error = AVERROR(ENOMEM);
-        goto cleanup;
+      goto cleanup;
     }
 
-    /** Save the encoder context for easiert access later. */
-    *output_codec_context = stream->codec;
-
-
-    /**
-     * Set the basic encoder parameters.
-     * The input file's sample rate is used to avoid a sample rate conversion.
-     */
-    (*output_codec_context)->channels       = OUTPUT_CHANNELS;
-    (*output_codec_context)->channel_layout = av_get_default_channel_layout(OUTPUT_CHANNELS);
-    (*output_codec_context)->sample_rate    = 48000; //Opus need 48000
-    (*output_codec_context)->sample_fmt     = AV_SAMPLE_FMT_S16;
-    (*output_codec_context)->bit_rate       = OUTPUT_BIT_RATE;
-
-	
-    /** Open the encoder for the audio stream to use it later. */
-    if ((error = avcodec_open2(*output_codec_context, output_codec, NULL)) < 0) {
+  /** Create a new audio stream in the output file container. */
+  if (!(stream = avformat_new_stream(*output_format_context, output_codec)))
+    {
 #if DEBUG
-        fprintf(stderr, "Could not open output codec (error '%s')\n",
-                get_error_text(error));
+      fprintf(stderr, "Could not create new stream\n");
 #endif
-        goto cleanup;
+      error = AVERROR(ENOMEM);
+      goto cleanup;
     }
 
-    return 0;
+  /** Save the encoder context for easiert access later. */
+  *output_codec_context = stream->codec;
+
+  /**
+   * Set the basic encoder parameters.
+   * The input file's sample rate is used to avoid a sample rate conversion.
+   */
+  (*output_codec_context)->channels       = OUTPUT_CHANNELS;
+  (*output_codec_context)->channel_layout = av_get_default_channel_layout(OUTPUT_CHANNELS);
+  (*output_codec_context)->sample_rate    = 48000; //Opus need 48000
+  (*output_codec_context)->sample_fmt     = AV_SAMPLE_FMT_S16;
+  (*output_codec_context)->bit_rate       = OUTPUT_BIT_RATE;
+
+  /** Open the encoder for the audio stream to use it later. */
+  if ((error = avcodec_open2(*output_codec_context, output_codec, NULL)) < 0)
+    {
+#if DEBUG
+      fprintf(stderr, "Could not open output codec (error '%s')\n",
+              get_error_text(error));
+#endif
+      goto cleanup;
+    }
+  return 0;
 
 cleanup:
-    return error < 0 ? error : AVERROR_EXIT;
+  av_free (io_ctx);
+  return error < 0 ? error : AVERROR_EXIT;
 }
 
+
 /** Initialize one data packet for reading or writing. */
-static void init_packet(AVPacket *packet)
+static void
+init_packet(AVPacket *packet)
 {
-    av_init_packet(packet);
-    /** Set the packet data and size so that it is recognized as being empty. */
-    packet->data = NULL;
-    packet->size = 0;
+  av_init_packet(packet);
+  /** Set the packet data and size so that it is recognized as being empty. */
+  packet->data = NULL;
+  packet->size = 0;
 }
 
+
 /** Initialize one audio frame for reading from the input file */
-static int init_input_frame(AVFrame **frame)
+static int
+init_input_frame(AVFrame **frame)
 {
 #if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(55,28,1)
-    *frame = av_frame_alloc ();
+  *frame = av_frame_alloc ();
 #else
-    *frame = avcodec_alloc_frame();
+  *frame = avcodec_alloc_frame();
 #endif
-    if (NULL == *frame) {
+  if (NULL == *frame)
+    {
 #if DEBUG
-        fprintf(stderr, "Could not allocate input frame\n");
+      fprintf(stderr, "Could not allocate input frame\n");
 #endif
-        return AVERROR(ENOMEM);
+      return AVERROR(ENOMEM);
     }
-    return 0;
+  return 0;
 }
 
+
 /**
  * Initialize the audio resampler based on the input and output codec settings.
  * If the input and output sample formats differ, a conversion is required
  * libavresample takes care of this, but requires initialization.
  */
-static int init_resampler(AVCodecContext *input_codec_context,
-                          AVCodecContext *output_codec_context,
-                          AVAudioResampleContext  **resample_context)
+static int
+init_resampler (AVCodecContext *input_codec_context,
+                AVCodecContext *output_codec_context,
+                AVAudioResampleContext  **resample_context)
 {
     /**
      * Only initialize the resampler if it is necessary, i.e.,
@@ -326,7 +336,7 @@ static int init_resampler(AVCodecContext *input_codec_context,
     if (input_codec_context->sample_fmt != output_codec_context->sample_fmt ||
         input_codec_context->channels != output_codec_context->channels) {
         int error;
-		
+
 		      /** Create a resampler context for the conversion. */
        if (!(*resample_context = avresample_alloc_context())) {
 #if DEBUG
@@ -334,7 +344,7 @@ static int init_resampler(AVCodecContext *input_codec_context,
 #endif
            return AVERROR(ENOMEM);
        }
-	   
+
 
         /**
          * Set the conversion parameters.
@@ -397,7 +407,7 @@ static int write_output_file_header(AVFormatContext *output_format_context)
 /** Decode one audio frame from the input file. */
 static int decode_audio_frame(AVFrame *frame,
                               AVFormatContext *input_format_context,
-                              AVCodecContext *input_codec_context, int audio_stream_index, 
+                              AVCodecContext *input_codec_context, int audio_stream_index,
                               int *data_present, int *finished)
 {
     /** Packet used for temporary storage. */
@@ -423,7 +433,7 @@ static int decode_audio_frame(AVFrame *frame,
 				return error;
 			}
 		}
-		
+
 		if(input_packet.stream_index == audio_stream_index)
 			break;
 	}
@@ -504,7 +514,7 @@ static int init_converted_samples(uint8_t ***converted_input_samples, int* out_l
  * by frame_size.
  */
 static int convert_samples(uint8_t **input_data,
-                           uint8_t **converted_data, const int in_sample, const int out_sample, const int out_linesize, 
+                           uint8_t **converted_data, const int in_sample, const int out_sample, const int out_linesize,
                            AVAudioResampleContext  *resample_context)
 {
     int error;
@@ -518,8 +528,8 @@ static int convert_samples(uint8_t **input_data,
 #endif
         return error;
     }
-	
-	 
+
+
     /**
      * Perform a sanity check so that the number of converted samples is
      * not greater than the number of samples to be converted.
@@ -588,7 +598,7 @@ static int read_decode_convert_and_store(AVAudioFifo *fifo,
 		fprintf(stderr, "Failed at init frame\n");
 #endif
 		goto cleanup;
-		
+
 		}
     /** Decode one frame worth of audio samples. */
     if (decode_audio_frame(input_frame, input_format_context,
@@ -596,9 +606,9 @@ static int read_decode_convert_and_store(AVAudioFifo *fifo,
 #if DEBUG
 		fprintf(stderr, "Failed at decode audio\n");
 #endif
-		
+
 		goto cleanup;
-		
+
 		}
     /**
      * If we are at the end of the file and there are no more samples
@@ -622,7 +632,7 @@ static int read_decode_convert_and_store(AVAudioFifo *fifo,
 		//fprintf(stderr, "Input nbsamples %i out_samples: %i \n",input_frame->nb_samples,out_samples);
 
         /** Initialize the temporary storage for the converted input samples. */
-        if (init_converted_samples(&converted_input_samples, &out_linesize, output_codec_context, 
+        if (init_converted_samples(&converted_input_samples, &out_linesize, output_codec_context,
                                    out_samples)){
 #if DEBUG
 		fprintf(stderr, "Failed at init_converted_samples\n");
@@ -636,8 +646,8 @@ static int read_decode_convert_and_store(AVAudioFifo *fifo,
          */
         if (convert_samples(input_frame->extended_data, converted_input_samples,
                             input_frame->nb_samples, out_samples, out_linesize ,resampler_context)){
-							
-							
+
+
 #if DEBUG
 		fprintf(stderr, "Failed at convert_samples, input frame %i \n",input_frame->nb_samples);
 #endif
@@ -704,10 +714,10 @@ static int init_output_frame(AVFrame **frame,
     (*frame)->format         = output_codec_context->sample_fmt;
     (*frame)->sample_rate    = output_codec_context->sample_rate;
 
-	
-	
-	  //fprintf(stderr, "%i %i  \n",frame_size , (*frame)->format,(*frame)->sample_rate); 
-	
+
+
+	  //fprintf(stderr, "%i %i  \n",frame_size , (*frame)->format,(*frame)->sample_rate);
+
     /**
      * Allocate the samples of the created frame. This call will make
      * sure that the audio frame can hold as many samples as specified.
@@ -745,7 +755,7 @@ static int encode_audio_frame(AVFrame *frame,
     if ((error = avcodec_encode_audio2(output_codec_context, &output_packet,
                                        frame, data_present)) < 0) {
 #if DEBUG
-		fprintf(stderr, "Could not encode frame (error '%s')\n",            
+		fprintf(stderr, "Could not encode frame (error '%s')\n",
 		get_error_text(error));
 #endif
         av_free_packet(&output_packet);
@@ -759,14 +769,14 @@ static int encode_audio_frame(AVFrame *frame,
 			fprintf(stderr, "Could not write frame (error '%s')\n",
 			get_error_text(error));
 #endif
-                    
+
             av_free_packet(&output_packet);
             return error;
         }
 
         av_free_packet(&output_packet);
     }
-	
+
     return 0;
 }
 
@@ -788,7 +798,7 @@ static int load_encode_and_write(AVAudioFifo *fifo,
     const int frame_size = FFMIN(av_audio_fifo_size(fifo),
                                  output_codec_context->frame_size);
     int data_written;
-	 
+
     /** Initialize temporary storage for one output frame. */
     if (init_output_frame(&output_frame, output_codec_context, frame_size))
         return AVERROR_EXIT;
@@ -832,7 +842,7 @@ static int write_output_file_trailer(AVFormatContext *output_format_context)
     int error;
     if ((error = av_write_trailer(output_format_context)) < 0) {
 #if DEBUG
-		fprintf(stderr, "Could not write output file trailer (error '%s')\n",    
+		fprintf(stderr, "Could not write output file trailer (error '%s')\n",
 		get_error_text(error));
 #endif
         return error;
@@ -861,21 +871,20 @@ extract_audio (struct EXTRACTOR_ExtractContext *ec)
   AVCodecContext* output_codec_context = NULL;
   AVAudioResampleContext  *resample_context = NULL;
   AVAudioFifo *fifo = NULL;
-	
-	
+
   int audio_stream_index;
   int i;
   int err;
   int duration;
   unsigned char *iob;
-  
-  
+
+
   totalSize =0;
-  
   if (NULL == (iob = av_malloc (16 * 1024)))
     return;
-  if (NULL == (io_ctx = avio_alloc_context (iob, 16 * 1024,
-					    0, ec, 
+  if (NULL == (io_ctx = avio_alloc_context (iob,
+                                            16 * 1024,
+					    0, ec,
 					    &read_cb,
 					    NULL /* no writing */,
 					    &seek_cb)))
@@ -891,8 +900,11 @@ extract_audio (struct EXTRACTOR_ExtractContext *ec)
   format_ctx->pb = io_ctx;
   options = NULL;
   if (0 != avformat_open_input (&format_ctx, "<no file>", NULL, &options))
-    return;
-  av_dict_free (&options);  
+    {
+      av_free (io_ctx);
+      return;
+    }
+  av_dict_free (&options);
   if (0 > avformat_find_stream_info (format_ctx, NULL))
     {
 #if DEBUG
@@ -919,7 +931,7 @@ extract_audio (struct EXTRACTOR_ExtractContext *ec)
           codec = NULL;
           continue;
         }
-      av_dict_free (&options); 
+      av_dict_free (&options);
       audio_stream_index = i;
       break;
     }
@@ -953,195 +965,199 @@ extract_audio (struct EXTRACTOR_ExtractContext *ec)
       av_free (io_ctx);
       return;
     }
-	
-	
-	if(!(buffer = malloc(HARD_LIMIT_SIZE)))
-		goto cleanup;
-	
-	
-	 /** Open the output file for writing. */
-    if (open_output_file( codec_ctx,&output_format_context, &output_codec_context))
-        goto cleanup;
-    /** Initialize the resampler to be able to convert audio sample formats. */
-    if (init_resampler(codec_ctx, output_codec_context,
-                       &resample_context))
-        goto cleanup;
-    /** Initialize the FIFO buffer to store audio samples to be encoded. */
-    if (init_fifo(&fifo))
-        goto cleanup;
-	
-	    /** Write the header of the output file container. */
-    if (write_output_file_header(output_format_context))
-        goto cleanup;
-	
+
+
+  if (! (buffer = malloc(HARD_LIMIT_SIZE)))
+    goto cleanup;
+
+
+  /** Open the output file for writing. */
+  if (open_output_file (codec_ctx,
+                        &output_format_context,
+                        &output_codec_context))
+    goto cleanup;
+  /** Initialize the resampler to be able to convert audio sample formats. */
+  if (init_resampler (codec_ctx,
+                      output_codec_context,
+                      &resample_context))
+    goto cleanup;
+  /** Initialize the FIFO buffer to store audio samples to be encoded. */
+  if (init_fifo(&fifo))
+    goto cleanup;
+
+  /** Write the header of the output file container. */
+  if (write_output_file_header(output_format_context))
+    goto cleanup;
+
 
   if (format_ctx->duration == AV_NOPTS_VALUE)
-	{
-	duration = -1;
+    {
+      duration = -1;
 #if DEBUG
-    fprintf (stderr,
-	     "Duration unknown\n");
+      fprintf (stderr,
+               "Duration unknown\n");
 #endif
-	}
+    }
   else
-  {
+    {
 #if DEBUG
-	duration = format_ctx->duration;
-    fprintf (stderr,
-	     "Duration: %lld\n", 
-	     format_ctx->duration);  
-#endif		 
-	}
-	
-	
+      duration = format_ctx->duration;
+      fprintf (stderr,
+               "Duration: %lld\n",
+               format_ctx->duration);
+#endif
+    }
 
   /* if duration is known, seek to first tried,
    * else use 10 sec into stream */
- 
+
   if(-1 != duration)
-	err = av_seek_frame (format_ctx, -1, (duration/3), 0);
+    err = av_seek_frame (format_ctx, -1, (duration/3), 0);
   else
-	err = av_seek_frame (format_ctx, -1, 10 * AV_TIME_BASE, 0);
-  
-  
-  
-  if (err >= 0)        
-    avcodec_flush_buffers (codec_ctx);        
+    err = av_seek_frame (format_ctx, -1, 10 * AV_TIME_BASE, 0);
 
 
-	/**
-     * Loop as long as we have input samples to read or output samples
-     * to write; abort as soon as we have neither.
-     */
-    while (1) {
-        /** Use the encoder's desired frame size for processing. */
-        const int output_frame_size = output_codec_context->frame_size;
-        int finished                = 0;
+  if (err >= 0)
+    avcodec_flush_buffers (codec_ctx);
 
-        /**
-         * Make sure that there is one frame worth of samples in the FIFO
-         * buffer so that the encoder can do its work.
-         * Since the decoder's and the encoder's frame size may differ, we
-         * need to FIFO buffer to store as many frames worth of input samples
-         * that they make up at least one frame worth of output samples.
-         */
-		 
-        while ((av_audio_fifo_size(fifo) < output_frame_size)) {
-            /**
-             * Decode one frame worth of audio samples, convert it to the
-             * output sample format and put it into the FIFO buffer.
-             */
 
-		 
-            if (read_decode_convert_and_store(fifo, format_ctx,codec_ctx,
-                                              output_codec_context,
-                                              resample_context,audio_stream_index, &finished)){
+  /**
+   * Loop as long as we have input samples to read or output samples
+   * to write; abort as soon as we have neither.
+   */
+  while (1)
+    {
+      /** Use the encoder's desired frame size for processing. */
+      const int output_frame_size = output_codec_context->frame_size;
+      int finished                = 0;
 
-                goto cleanup;
-				
-				}
+      /**
+       * Make sure that there is one frame worth of samples in the FIFO
+       * buffer so that the encoder can do its work.
+       * Since the decoder's and the encoder's frame size may differ, we
+       * need to FIFO buffer to store as many frames worth of input samples
+       * that they make up at least one frame worth of output samples.
+       */
 
-            /**
-             * If we are at the end of the input file, we continue
-             * encoding the remaining audio samples to the output file.
-             */
-            if (finished)
-                break;
-        }
+      while ((av_audio_fifo_size(fifo) < output_frame_size))
+        {
+          /**
+           * Decode one frame worth of audio samples, convert it to the
+           * output sample format and put it into the FIFO buffer.
+           */
+          if (read_decode_convert_and_store (fifo,
+                                             format_ctx,
+                                             codec_ctx,
+                                             output_codec_context,
+                                             resample_context,
+                                             audio_stream_index,
+                                             &finished))
+            {
+              goto cleanup;
+            }
 
-		/* Already over our limit*/
-		if(totalSize >= MAX_SIZE)
-			finished = 1;
-		
-		
-        /**
-         * If we have enough samples for the encoder, we encode them.
-         * At the end of the file, we pass the remaining samples to
-         * the encoder.
-         */
-
-        while (av_audio_fifo_size(fifo) >= output_frame_size ||
-               (finished && av_audio_fifo_size(fifo) > 0)){
-            /**
-             * Take one frame worth of audio samples from the FIFO buffer,
-             * encode it and write it to the output file.
-             */
-
-		 
-            if (load_encode_and_write(fifo,output_format_context,  output_codec_context))
-                goto cleanup;
-			}
-        /**
-         * If we are at the end of the input file and have encoded
-         * all remaining samples, we can exit this loop and finish.
-         */
-        if (finished) {
-            int data_written;
-            /** Flush the encoder as it may have delayed frames. */
-            do {
-                encode_audio_frame(NULL, output_format_context, output_codec_context, &data_written);
-            } while (data_written);
+          /**
+           * If we are at the end of the input file, we continue
+           * encoding the remaining audio samples to the output file.
+           */
+          if (finished)
             break;
         }
+
+      /* Already over our limit*/
+      if (totalSize >= MAX_SIZE)
+        finished = 1;
+
+      /**
+       * If we have enough samples for the encoder, we encode them.
+       * At the end of the file, we pass the remaining samples to
+       * the encoder.
+       */
+
+      while (av_audio_fifo_size(fifo) >= output_frame_size ||
+             (finished && av_audio_fifo_size(fifo) > 0))
+        {
+          /**
+           * Take one frame worth of audio samples from the FIFO buffer,
+           * encode it and write it to the output file.
+           */
+          if (load_encode_and_write (fifo,
+                                     output_format_context,
+                                     output_codec_context))
+            goto cleanup;
+        }
+      /**
+       * If we are at the end of the input file and have encoded
+       * all remaining samples, we can exit this loop and finish.
+       */
+      if (finished)
+        {
+          int data_written;
+          /** Flush the encoder as it may have delayed frames. */
+          do {
+            encode_audio_frame (NULL,
+                                output_format_context,
+                                output_codec_context,
+                                &data_written);
+          } while (data_written);
+          break;
+        }
     }
 
-    /** Write the trailer of the output file container. */
-    if (write_output_file_trailer(output_format_context))
-        goto cleanup;
-		
+  /** Write the trailer of the output file container. */
+  if (write_output_file_trailer(output_format_context))
+    goto cleanup;
+  ec->proc (ec->cls,
+            "previewopus",
+            EXTRACTOR_METATYPE_AUDIO_PREVIEW,
+            EXTRACTOR_METAFORMAT_BINARY,
+            "audio/opus",
+            buffer,
+            totalSize);
 
-    ec->proc (ec->cls,
-		"previewopus",
-		EXTRACTOR_METATYPE_AUDIO_PREVIEW,
-		EXTRACTOR_METAFORMAT_BINARY,
-		"audio/opus",
-		buffer,
-		totalSize);
-		
-		
 #if OUTPUT_FILE
-	FILE *f;
-	f = fopen("example.opus", "wb");
-    if (!f) {
-        fprintf(stderr, "Could not open %s\n", "file");
-        exit(1);
-    }
-	
-	fwrite(buffer, 1, totalSize, f);
-	fclose(f);
+  {
+    FILE *f;
 
+    f = fopen ("example.opus", "wb");
+    if (!f)
+      {
+        fprintf (stderr, "Could not open %s\n", "file");
+        exit(1);
+      }
+    fwrite (buffer, 1, totalSize, f);
+    fclose(f);
+  }
 #endif
 
-
-  cleanup:
+ cleanup:
   av_free (frame);
-  
-  free(buffer);
-  
-    if (fifo)
-        av_audio_fifo_free(fifo);
-	if (resample_context) {
-		avresample_close(resample_context);
-		avresample_free(&resample_context);
-	}
-    if (output_codec_context)
-        avcodec_close(output_codec_context);
+  free (buffer);
 
-    if (codec_ctx)
-        avcodec_close(codec_ctx);
-    if (format_ctx)
-        avformat_close_input(&format_ctx);
-	av_free (io_ctx);
-		
-		
+  if (fifo)
+    av_audio_fifo_free(fifo);
+  if (resample_context)
+    {
+      avresample_close(resample_context);
+      avresample_free(&resample_context);
+    }
+  if (output_codec_context)
+    avcodec_close(output_codec_context);
+
+  if (codec_ctx)
+    avcodec_close(codec_ctx);
+  if (format_ctx)
+    avformat_close_input(&format_ctx);
+  av_free (io_ctx);
 }
 
+
 /**
  * Main method for the opus-preview plugin.
  *
  * @param ec extraction context
  */
-void 
+void
 EXTRACTOR_previewopus_extract_method (struct EXTRACTOR_ExtractContext *ec)
 {
   ssize_t iret;
@@ -1160,7 +1176,6 @@ EXTRACTOR_previewopus_extract_method (struct EXTRACTOR_ExtractContext *ec)
 }
 
 
-
 /**
  * Log callback.  Does nothing.
  *
@@ -1169,8 +1184,8 @@ EXTRACTOR_previewopus_extract_method (struct EXTRACTOR_ExtractContext *ec)
  * @param format format string
  * @param ap arguments for format
  */
-static void 
-previewopus_av_log_callback (void* ptr, 
+static void
+previewopus_av_log_callback (void* ptr,
 				 int level,
 				 const char *format,
 				 va_list ap)
@@ -1184,7 +1199,7 @@ previewopus_av_log_callback (void* ptr,
 /**
  * Initialize av-libs
  */
-void __attribute__ ((constructor)) 
+void __attribute__ ((constructor))
 previewopus_lib_init (void)
 {
   av_log_set_callback (&previewopus_av_log_callback);
@@ -1196,8 +1211,8 @@ previewopus_lib_init (void)
 /**
  * Destructor for the library, cleans up.
  */
-void __attribute__ ((destructor)) 
-previewopus_ltdl_fini () 
+void __attribute__ ((destructor))
+previewopus_ltdl_fini ()
 {
 
 }
