@@ -635,7 +635,8 @@ extract_video (struct EXTRACTOR_ExtractContext *ec)
 
   if (NULL == (iob = av_malloc (16 * 1024)))
     return;
-  if (NULL == (io_ctx = avio_alloc_context (iob, 16 * 1024,
+  if (NULL == (io_ctx = avio_alloc_context (iob,
+                                            16 * 1024,
 					    0, ec,
 					    &read_cb,
 					    NULL /* no writing */,
@@ -652,7 +653,10 @@ extract_video (struct EXTRACTOR_ExtractContext *ec)
   format_ctx->pb = io_ctx;
   options = NULL;
   if (0 != avformat_open_input (&format_ctx, "<no file>", NULL, &options))
-    return;
+    {
+      av_free (io_ctx);
+      return;
+    }
   av_dict_free (&options);
   if (0 > avformat_find_stream_info (format_ctx, NULL))
     {
@@ -789,7 +793,6 @@ extract_video (struct EXTRACTOR_ExtractContext *ec)
                           &encoded_thumbnail, MAX_THUMB_BYTES);
   if (err > 0)
     {
-
       ec->proc (ec->cls,
 		"thumbnailffmpeg",
 		EXTRACTOR_METATYPE_THUMBNAIL,
@@ -797,22 +800,22 @@ extract_video (struct EXTRACTOR_ExtractContext *ec)
 		"image/png",
 		(const char*) encoded_thumbnail,
 		err);
-		#if OUTPUT_FILE
-        	FILE *f;
-			#ifdef USE_JPEG
-        	f = fopen("thumb.jpg", "wb");
-			#else
-			f = fopen("thumb.png", "wb");
-			#endif
-            if (!f) {
-                fprintf(stderr, "Could not open %s\n", "file");
-                exit(1);
-            }
+#if OUTPUT_FILE
+      FILE *f;
+#ifdef USE_JPEG
+      f = fopen("thumb.jpg", "wb");
+#else
+      f = fopen("thumb.png", "wb");
+#endif
+      if (!f)
+        {
+          fprintf(stderr, "Could not open %s\n", "file");
+          exit(1);
+        }
 
-        	fwrite(encoded_thumbnail, 1, err, f);
-        	fclose(f);
-
-        #endif
+      fwrite(encoded_thumbnail, 1, err, f);
+      fclose(f);
+#endif
       av_free (encoded_thumbnail);
     }
 #if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(55,28,1)
