@@ -83,7 +83,7 @@ EXTRACTOR_xm_extract_method (struct EXTRACTOR_ExtractContext *ec)
   /* Version of Tracker */
   snprintf (xmversion,
 	    sizeof (xmversion),
-	    "%d.%d",
+	    "%u.%u",
 	    head->version[1],
 	    head->version[0]);
   ADD (xmversion, EXTRACTOR_METATYPE_FORMAT_VERSION);
